==> haskell-hint-0.9.0.2-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hint
version:              0.9.0.2
visibility:           public
id:                   hint-0.9.0.2-Cnl5oPuOuvqCpWwqiHbrOy
key:                  hint-0.9.0.2-Cnl5oPuOuvqCpWwqiHbrOy
license:              BSD-3-Clause
maintainer:           mvdan@mvdan.cc
author:               The Hint Authors
homepage:             https://github.com/haskell-hint/hint
synopsis:             Runtime Haskell interpreter (GHC API wrapper)
description:
    This library defines an Interpreter monad. It allows to load Haskell
    modules, browse them, type-check and evaluate strings with Haskell
    expressions and even coerce them into values. The library is thread-safe
    and type-safe (even the coercion of expressions to values).
    It is, essentially, a huge subset of the GHC API wrapped in a simpler
    API.

category:             Language, Compilers/Interpreters
abi:                  36d72e09b17c8f34d3f2ba3617a90431
exposed:              True
exposed-modules:
    Hint.Internal Language.Haskell.Interpreter
    Language.Haskell.Interpreter.Extension
    Language.Haskell.Interpreter.Unsafe

hidden-modules:
    Hint.GHC Hint.Base Hint.InterpreterT Hint.CompatPlatform
    Hint.Configuration Hint.Extension Hint.Context Hint.Conversions
    Hint.Eval Hint.Parsers Hint.Reflection Hint.Typecheck Hint.Util
    Hint.Annotations Control.Monad.Ghc

import-dirs:          /usr/lib/ghc-8.8.2/site-local/hint-0.9.0.2
library-dirs:         /usr/lib/ghc-8.8.2/site-local/hint-0.9.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/hint-0.9.0.2
hs-libraries:         HShint-0.9.0.2-Cnl5oPuOuvqCpWwqiHbrOy
depends:
    base-4.13.0.0 directory-1.3.4.0
    exceptions-0.10.4-AcCA76Y0j0oK3rQoxPMQMv filepath-1.4.2.1 ghc-8.8.2
    ghc-boot-8.8.2 ghc-paths-0.1.0.12-6yfxCcKnGxxC3UhlLpLlce mtl-2.2.2
    random-1.1-CUqV1zxrwrE4K5XCdTZSYy
    temporary-1.3-A2E15CezfCB3wTfNqjqKzK unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-hint/html/hint.haddock
haddock-html:         /usr/share/doc/haskell-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hint-0.9.0.2-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hint
version:              0.9.0.2
visibility:           public
id:                   hint-0.9.0.2-3Ky87sivHzX8E6eZx3KM9R
key:                  hint-0.9.0.2-3Ky87sivHzX8E6eZx3KM9R
license:              BSD-3-Clause
maintainer:           mvdan@mvdan.cc
author:               The Hint Authors
homepage:             https://github.com/haskell-hint/hint
synopsis:             Runtime Haskell interpreter (GHC API wrapper)
description:
    This library defines an Interpreter monad. It allows to load Haskell
    modules, browse them, type-check and evaluate strings with Haskell
    expressions and even coerce them into values. The library is thread-safe
    and type-safe (even the coercion of expressions to values).
    It is, essentially, a huge subset of the GHC API wrapped in a simpler
    API.

category:             Language, Compilers/Interpreters
abi:                  0eddff50256627c352a0c75b173f31ad
exposed:              True
exposed-modules:
    Hint.Internal Language.Haskell.Interpreter
    Language.Haskell.Interpreter.Extension
    Language.Haskell.Interpreter.Unsafe

hidden-modules:
    Hint.GHC Hint.Base Hint.InterpreterT Hint.CompatPlatform
    Hint.Configuration Hint.Extension Hint.Context Hint.Conversions
    Hint.Eval Hint.Parsers Hint.Reflection Hint.Typecheck Hint.Util
    Hint.Annotations Control.Monad.Ghc

import-dirs:          /usr/lib/ghc-8.8.3/site-local/hint-0.9.0.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/hint-0.9.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/hint-0.9.0.2
hs-libraries:         HShint-0.9.0.2-3Ky87sivHzX8E6eZx3KM9R
depends:
    base-4.13.0.0 directory-1.3.6.0
    exceptions-0.10.4-JUrZHue9S26DL7DmYQK2uL filepath-1.4.2.1 ghc-8.8.3
    ghc-boot-8.8.3 ghc-paths-0.1.0.12-6yfxCcKnGxxC3UhlLpLlce mtl-2.2.2
    random-1.1-CUqV1zxrwrE4K5XCdTZSYy
    temporary-1.3-BLzMLpRlVKa3StoSFR54tr unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-hint/html/hint.haddock
haddock-html:         /usr/share/doc/haskell-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
